"""VHDLTest application entry module."""

from .VHDLTest import VHDLTest


def main() -> None:
    """Run the VHDLTest class."""
    VHDLTest().run()


if __name__ == '__main__':
    main()
